@@ -578,7 +578,7 @@ add_local_metadata (TotemGrilo *self,
 	}
 
 	options = grl_operation_options_new (NULL);
-	grl_operation_options_set_flags (options, GRL_RESOLVE_NORMAL);
+	grl_operation_options_set_resolution_flags (options, GRL_RESOLVE_NORMAL);
 	grl_source_resolve_sync (self->priv->local_metadata_src,
 				 media,
 				 self->priv->metadata_keys,
@@ -734,7 +734,7 @@ browse (TotemGrilo   *self,
 	caps = grl_source_get_caps (source, GRL_OP_BROWSE);
 
 	default_options = grl_operation_options_new (NULL);
-	grl_operation_options_set_flags (default_options, BROWSE_FLAGS);
+	grl_operation_options_set_resolution_flags (default_options, BROWSE_FLAGS);
 	if (page >= 1) {
 		grl_operation_options_set_skip (default_options, (page - 1) * PAGE_SIZE);
 		grl_operation_options_set_count (default_options, PAGE_SIZE);
@@ -843,7 +843,7 @@ get_search_options (TotemGrilo *self)
 	GrlOperationOptions *supported_options;
 
 	default_options = grl_operation_options_new (NULL);
-	grl_operation_options_set_flags (default_options, BROWSE_FLAGS);
+	grl_operation_options_set_resolution_flags (default_options, BROWSE_FLAGS);
 	grl_operation_options_set_skip (default_options, self->priv->search_page * PAGE_SIZE);
 	grl_operation_options_set_count (default_options, PAGE_SIZE);
 	grl_operation_options_set_type_filter (default_options, GRL_TYPE_FILTER_VIDEO);
@@ -1282,8 +1282,7 @@ source_added_cb (GrlRegistry *registry,
 		if (source_is_recent (source)) {
 			browse (self, self->priv->recent_model,
 				NULL, source, NULL, -1);
-			if (g_str_equal (id, "grl-tracker-source") == FALSE)
-				monitor = TRUE;
+			monitor = TRUE;
 		} else if (!source_is_browse_blacklisted (source)) {
 			const GdkPixbuf *icon;
 
@@ -1298,12 +1297,12 @@ source_added_cb (GrlRegistry *registry,
 							   MODEL_RESULTS_IS_PRETHUMBNAIL, TRUE,
 							   MODEL_RESULTS_CAN_REMOVE, can_remove (source, NULL),
 							   -1);
-
-			if (g_str_equal (id, "grl-filesystem") == FALSE)
-				monitor = TRUE;
+			monitor = TRUE;
 		}
 
-		if (monitor && (ops & GRL_OP_NOTIFY_CHANGE)) {
+		if (monitor &&
+		    (ops & GRL_OP_NOTIFY_CHANGE) &&
+		    g_str_equal (id, "grl-filesystem") == FALSE) {
 			grl_source_notify_change_start (source, NULL);
 			g_signal_connect (G_OBJECT (source), "content-changed",
 					  G_CALLBACK (content_changed_cb), self);
@@ -1850,6 +1849,7 @@ setup_source_switcher (TotemGrilo *self)
 	GtkStyleContext *context;
 
 	self->priv->switcher = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+	gtk_box_set_homogeneous (GTK_BOX (self->priv->switcher), TRUE);
 
 	self->priv->recent = create_switcher_button (self, _("Videos"), "recent");
 	gtk_container_add (GTK_CONTAINER (self->priv->switcher), self->priv->recent);
@@ -2487,8 +2487,6 @@ totem_grilo_finalize (GObject *object)
 void
 totem_grilo_start (TotemGrilo *self)
 {
-	g_debug ("TotemGrilo: Resuming videos thumbnailing");
-
 	totem_grilo_resume_icon_thumbnailing ();
 
 	if (self->priv->plugins_loaded)
@@ -2503,7 +2501,6 @@ totem_grilo_start (TotemGrilo *self)
 void
 totem_grilo_pause (TotemGrilo *self)
 {
-	g_debug ("TotemGrilo: Pausing videos thumbnailing");
 	totem_grilo_pause_icon_thumbnailing ();
 }
 
